@@ -580,8 +580,7 @@ class Create(Base):
                 filename.decode('utf-8'))
             if context.get(new_id, None):
                 IStatusMessage(context.REQUEST).addStatusMessage(
-                    _(u"A File with this id already exists,\
-                    the File wasn't uploaded"), type='error')
+                    _(u"text_file_exists_error"), type='error')
                 context.setAttachment('DELETE_FILE')
                 return self.request.response.redirect(context.absolute_url())
             new_file_id = context.invokeFactory(
